=head1 NAME

Catalyst::Manual::Plugins - See Catalyst::Manual::Components instead 

=head1 SEE INSTEAD

L<Catalyst::Manual::Components>

=cut

=head1 AUTHORS

Catalyst Contributors, see Catalyst.pm

=head1 COPYRIGHT

This library is free software. You can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

